@@ -23,6 +23,7 @@ class MonorepoPlugin(BasePlugin):
         self.merger = None
         self.originalDocsDir = None
         self.resolvedPaths = []
+        self.files_source_dir = {}
 
     def on_config(self, config):
         # If no 'nav' defined, we don't need to run.
@@ -49,8 +50,18 @@ class MonorepoPlugin(BasePlugin):
         # Store resolved paths for later.
         self.resolvedPaths = resolvedPaths
 
+        # Store source directory of copied files for later
+        self.files_source_dir = self.merger.getFilesSourceFolder()
+
         return config
 
+    def on_pre_page(self, page, config, files):
+        # Update page source attribute to point to source file
+        # Only in case any files were moved.
+        if len(self.files_source_dir) > 0:
+            page.file.abs_src_path = self.files_source_dir[page.file.abs_src_path]
+        return page
+
     def on_serve(self, server, config, **kwargs):
         buildfunc = list(server.watcher._tasks.values())[0]['func']
 
